aboutsummaryrefslogtreecommitdiffstats
path: root/resources
diff options
context:
space:
mode:
authorZdeno Olsovsky <zolsovsk@cisco.com>2016-09-28 16:25:44 +0200
committerPeter Mikus <pmikus@cisco.com>2016-10-07 10:22:32 +0000
commitd0ed91ffa2a529252d50fc241c0b481196e975e5 (patch)
tree42e60bb30c22ae26b00c1bbeb0a678cf921e2f89 /resources
parentb5096b75637e5ed91f81b94eb3ad06bea141155e (diff)
CSIT-257: L2enc - l2-eth-lispgpe-ip4 - L2BD
Change-Id: I0ee68f707c4175940538654f3a4bbd7d1a91bef1 Signed-off-by: Zdeno Olsovsky <zolsovsk@cisco.com>
Diffstat (limited to 'resources')
-rw-r--r--resources/libraries/python/LispSetup.py55
-rw-r--r--resources/libraries/robot/lisp/l2lisp.robot77
-rw-r--r--resources/templates/vat/lisp/add_lisp_adjacency.vat2
-rw-r--r--resources/templates/vat/lisp/add_lisp_remote_mapping.vat2
-rw-r--r--resources/templates/vat/lisp/lisp_eid_table_add_del_map.vat1
-rw-r--r--resources/test_data/lisp/l2/l2_ipv4.py47
6 files changed, 176 insertions, 8 deletions
diff --git a/resources/libraries/robot/lisp/l2lisp.robot b/resources/libraries/robot/lisp/l2lisp.robot
new file mode 100644
index 0000000000..78bca5487c
--- /dev/null
+++ b/resources/libraries/robot/lisp/l2lisp.robot
@@ -0,0 +1,77 @@
+# Copyright (c) 2016 Cisco and/or its affiliates.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at:
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+*** Settings ***
+| Documentation | LISP-gpe encapsulation suite keywords
+| Library | resources.libraries.python.topology.Topology
+| Resource | resources/libraries/robot/lisp/lisp_api.robot
+| Library | resources.libraries.python.LispSetup.LispLocatorSet
+| Library | resources.libraries.python.LispSetup.LispLocator
+| Library | resources.libraries.python.LispSetup.LispLocalEid
+| Library | resources.libraries.python.LispSetup.LispAdjacency
+| Library | resources.libraries.python.LispSetup.LispRemoteMapping
+| Library | resources.libraries.python.LispSetup.LispMapResolver
+| Library | resources.libraries.python.LispSetup.LispEidTableMap
+
+*** Keywords ***
+| Set up L2 Lisp on DUT
+| | [Documentation] | Set up LISP L2 topology.
+| | ...
+| | ... | *Arguments:*
+| | ... | - dut_node - DUT node. Type: dictionary
+| | ... | - adjacency - DUT static adjacency settings. Type: dict
+| | ... | - settings - DUT other LISP related settings. Type: dict
+| | ...
+| | ... | *Return:*
+| | ... | - No value returned
+| | ...
+| | ... | *Example:*
+| | ... | \| Set up LISP GPE topology \| ${dut_node} \| ${adjacency} \
+| | ... | \| ${settings} \|
+| | ...
+| | [Arguments]
+| | ... | ${dut_node} | ${adjacency} | ${settings}
+| | ...
+| | ${int_idx}= | Get Interface Sw Index | ${dut_node} | ${${adjacency['int']}}
+| | Enable Lisp | ${dut_node}
+| | Vpp Add Lisp Locator Set | ${dut_node}
+| | ... | ${settings['locator_name']}
+| | Vpp Add Lisp Locator | ${dut_node}
+| | ... | ${settings['locator_name']}
+| | ... | ${int_idx}
+| | ... | ${settings['priority']}
+| | ... | ${settings['weight']}
+| | Vpp Lisp Eid Table Mapping | ${dut_node}
+| | ... | ${settings['vni']}
+| | ... | bd=${settings['bd']}
+| | Vpp Add Lisp Local Eid | ${dut_node}
+| | ... | ${settings['locator_name']}
+| | ... | ${settings['vni']}
+| | ... | ${adjacency['seid']}
+| | Vpp Add Map Resolver | ${dut_node}
+| | ... | ${adjacency['map_res']}
+| | Vpp Add Lisp Remote Mapping | ${dut_node}
+| | ... | ${settings['vni']}
+| | ... | ${adjacency['eid']}
+| | ... | 0
+| | ... | ${adjacency['seid']}
+| | ... | 0
+| | ... | ${adjacency['rloc']}
+| | ... | is_mac=${TRUE}
+| | Vpp Add Lisp Adjacency | ${dut_node}
+| | ... | ${settings['vni']}
+| | ... | ${adjacency['eid']}
+| | ... | 0
+| | ... | ${adjacency['seid']}
+| | ... | 0
+| | ... | is_mac=${TRUE}
diff --git a/resources/templates/vat/lisp/add_lisp_adjacency.vat b/resources/templates/vat/lisp/add_lisp_adjacency.vat
index 3ffbb7f2a6..9c33625f6b 100644
--- a/resources/templates/vat/lisp/add_lisp_adjacency.vat
+++ b/resources/templates/vat/lisp/add_lisp_adjacency.vat
@@ -1 +1 @@
-lisp_add_del_adjacency add vni {vni} reid {deid}/{deid_prefix} leid {seid}/{seid_prefix}
+lisp_add_del_adjacency add vni {vni} reid {deid}{deid_prefix} leid {seid}{seid_prefix}
diff --git a/resources/templates/vat/lisp/add_lisp_remote_mapping.vat b/resources/templates/vat/lisp/add_lisp_remote_mapping.vat
index 48d89eebe5..6dcb4f91cd 100644
--- a/resources/templates/vat/lisp/add_lisp_remote_mapping.vat
+++ b/resources/templates/vat/lisp/add_lisp_remote_mapping.vat
@@ -1 +1 @@
-lisp_add_del_remote_mapping add vni {vni} eid {deid}/{deid_prefix} seid {seid}/{seid_prefix} rloc {rloc}
+lisp_add_del_remote_mapping add vni {vni} eid {deid}{deid_prefix} seid {seid}{seid_prefix} rloc {rloc}
diff --git a/resources/templates/vat/lisp/lisp_eid_table_add_del_map.vat b/resources/templates/vat/lisp/lisp_eid_table_add_del_map.vat
new file mode 100644
index 0000000000..beba91c60a
--- /dev/null
+++ b/resources/templates/vat/lisp/lisp_eid_table_add_del_map.vat
@@ -0,0 +1 @@
+lisp_eid_table_add_del_map vni {vni} {bd_or_vrf} \ No newline at end of file
diff --git a/resources/test_data/lisp/l2/l2_ipv4.py b/resources/test_data/lisp/l2/l2_ipv4.py
new file mode 100644
index 0000000000..7edccbc9ca
--- /dev/null
+++ b/resources/test_data/lisp/l2/l2_ipv4.py
@@ -0,0 +1,47 @@
+# Copyright (c) 2016 Cisco and/or its affiliates.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at:
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+"""Test variables for Eth-IPv4-ICMPv4-LISPGpe-IP4 encapsulation test suite."""
+
+# Lisp default global value
+locator_name = 'tst_locator'
+
+# Lisp default locator_set value
+lisp_dut_settings = {'locator_name': locator_name,
+ 'priority': 1,
+ 'weight': 1,
+ 'bd': 10,
+ 'vni': 5}
+
+# IPv4 Lisp static mapping configuration
+dut1_to_dut2_ip4 = '10.0.3.1'
+dut2_to_dut1_ip4 = '10.0.3.2'
+dut1_to_tg_ip4 = '10.0.1.1'
+dut2_to_tg_ip4 = '10.0.2.1'
+tg1_ip4 = '10.0.1.2'
+tg2_ip4 = '10.0.2.2'
+prefix4 = 24
+vpp_bd_id = 10
+tg_if1_mac = '08:22:22:22:22:11'
+tg_if2_mac = '08:22:22:22:22:22'
+
+dut1_to_dut2_ip4_static_adjacency = {'eid': tg_if2_mac,
+ 'seid': tg_if1_mac,
+ 'rloc': dut2_to_dut1_ip4,
+ 'int': 'dut1_to_dut2',
+ 'map_res': '10.0.0.2'}
+dut2_to_dut1_ip4_static_adjacency = {'eid': tg_if1_mac,
+ 'seid': tg_if2_mac,
+ 'rloc': dut1_to_dut2_ip4,
+ 'map_res': '10.0.0.1',
+ 'int': 'dut2_to_dut1'}
diff --git a/resources/libraries/python/LispSetup.py b/resources/libraries/python/LispSetup.py
index 99e3de8f74..85749955e7 100644
--- a/resources/libraries/python/LispSetup.py
+++ b/resources/libraries/python/LispSetup.py
@@ -46,16 +46,17 @@ class LispRemoteMapping(object):
@staticmethod
def vpp_add_lisp_remote_mapping(node, vni, deid, deid_prefix, seid,
- seid_prefix, rloc):
+ seid_prefix, rloc, is_mac=False):
"""Add lisp remote mapping on the VPP node in topology.
:param node: VPP node.
:param vni: Vni.
:param deid: Destination eid address.
:param deid_predix: Destination eid address prefix_len.
:param seid: Source eid address.
:param seid_prefix: Source eid address prefix_len.
:param rloc: Receiver locator.
+ :param is_mac: Set to True if the deid/seid is MAC address.
:type node: dict
:type vni: int
:type deid: str
@@ -63,8 +64,14 @@ class LispRemoteMapping(object):
:type seid: str
:type seid_prefix: int
:type rloc: str
+ :type is_mac: bool
"""
-
+ if is_mac:
+ deid_prefix = ''
+ seid_prefix = ''
+ else:
+ deid_prefix = '/{}'.format(deid_prefix)
+ seid_prefix = '/{}'.format(seid_prefix)
VatExecutor.cmd_from_template(node,
'lisp/add_lisp_remote_mapping.vat',
vni=vni,
@@ -82,7 +89,7 @@ class LispRemoteMapping(object):
:param node: VPP node.
:param vni: Vni.
:param deid: Destination eid address.
:param deid_predix: Destination eid address prefix_len.
:param seid: Source eid address.
:param seid_prefix: Source eid address prefix_len.
:param rloc: Receiver locator.
@@ -113,7 +120,7 @@ class LispAdjacency(object):
@staticmethod
def vpp_add_lisp_adjacency(node, vni, deid, deid_prefix, seid,
- seid_prefix):
+ seid_prefix, is_mac=False):
"""Add lisp adjacency on the VPP node in topology.
:param node: VPP node.
@@ -122,14 +129,21 @@ class LispAdjacency(object):
:param deid_prefix: Destination eid address prefix_len.
:param seid: Source eid address.
:param seid_prefix: Source eid address prefix_len.
+ :param is_mac: Set to True if the deid/seid is MAC address.
:type node: dict
:type vni: int
:type deid: str
:type deid_prefix: int
:type seid: str
:type seid_prefix: int
+ :type is_mac: bool
"""
-
+ if is_mac:
+ deid_prefix = ''
+ seid_prefix = ''
+ else:
+ deid_prefix = '/{}'.format(deid_prefix)
+ seid_prefix = '/{}'.format(seid_prefix)
VatExecutor.cmd_from_template(node,
'lisp/add_lisp_adjacency.vat',
vni=vni,
@@ -588,3 +602,32 @@ class LispSetup(object):
lgi = LispGpeIface()
lgi.vpp_lisp_gpe_iface(node, state)
+
+
+class LispEidTableMap(object):
+ """
+ Class for EID table map.
+ """
+
+ @staticmethod
+ def vpp_lisp_eid_table_mapping(node, vni, bd=None, vrf=None):
+ """
+ Map LISP VNI to either bridge domain ID, or VRF ID.
+
+ :param node: VPP node.
+ :param vni: Lisp VNI.
+ :param bd: Bridge domain ID.
+ :param vrf: VRF id.
+ :type node: dict
+ :type vni: int
+ :type bd: int
+ :type vrf: int
+ """
+ if bd:
+ bd_or_vrf = 'bd_index {}'.format(bd)
+ else:
+ bd_or_vrf = 'vrf {}'.format(vrf)
+ VatExecutor.cmd_from_template(node,
+ 'lisp/lisp_eid_table_add_del_map.vat',
+ vni=vni,
+ bd_or_vrf=bd_or_vrf)
@@ -46,16 +46,17 @@ class LispRemoteMapping(object):
:param vni: Vni.
:param deid: Destination eid address.
- :param deid_predix: Destination eid address prefix_len.
+ :param deid_prefix: Destination eid address prefix_len.
:param seid: Source eid address.
:param seid_prefix: Source eid address prefix_len.
@@ -82,7 +89,7 @@ class LispRemoteMapping(object):
:param vni: Vni.
:param deid: Destination eid address.
- :param deid_predix: Destination eid address prefix_len.
+ :param deid_prefix: Destination eid address prefix_len.
:param seid: Source eid address.
:param seid_prefix: Source eid address prefix_len.